package com.palnet.board.app.jw.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.palnet.board.app.jw.dto.JwBoardDto;
import com.palnet.board.app.jw.service.JwBoardService;

import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@RestController
@RequestMapping("/api/jw/board")
public class JwBoardRestController {

	final static Logger log = LoggerFactory.getLogger(JwBoardRestController.class);

	private final JwBoardService BoardService;

	// 글 목록 조회
	@GetMapping("/list")
	public List<JwBoardDto> list() {
		return BoardService.list();
	}

	// 글 상세 조회
	@GetMapping("/detail/{id}")
	public JwBoardDto detail(@PathVariable Integer id) {

		return BoardService.detail(id);
	}

	// 글 등록
	@PostMapping("/create")
	public Map create(@RequestBody JwBoardDto rq) {
		Map<String, String> res = new HashMap<>();
		try {
			int cnt = BoardService.create(rq);
			if (cnt > 0) {
				res.put("result", "success");
			} else {
				res.put("result", "fail");
			}
		} catch (Exception e) {
			log.error("{}", e);
			res.put("result", "fail");
		}
		return res;
	}

	// 글 수정
	@PutMapping("/modify/{id}")
	public Map update(@RequestBody JwBoardDto rq) {
		Map<String, String> res = new HashMap<>();
		try {
			int cnt = BoardService.update(rq);
			if (cnt > 0) {
				res.put("result", "success");
			} else {
				res.put("result", "fail");
			}
		} catch (Exception e) {
			log.error("{}", e);
			res.put("result", "fail");
		}
		return res;
	}

	// 글 삭제
	@DeleteMapping("/delete/{id}")
	public Map delete(@PathVariable Integer id) {
		Map<String, String> res = new HashMap<>();
		try {
			int cnt = BoardService.delete(id);
			if (cnt > 0) {
				res.put("result", "success");
			} else {
				res.put("result", "fail");
			}
		} catch (Exception e) {
			log.error("{}", e);
			res.put("result", "fail");
		}
		return res;
	}

	@PostMapping("/post")
	public String post(@RequestBody JwBoardDto boardDto) {
		log.debug(">> {}", boardDto);
		log.info(">> {}", boardDto);
		BoardService.create(boardDto);
		return "{}";
	}
	
	@GetMapping("/index")
	public ResponseEntity<Integer> index() throws Exception{
		int index = BoardService.index();
		return ResponseEntity.status(HttpStatus.OK).body(index);
	}
	

}
